/*
 * (C) Copyright 2012 Nuxeo SA (http://nuxeo.com/) and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Contributors:
 *     Thierry Delprat
 */
package org.nuxeo.ecm.platform.template.tests;

import java.io.File;
import java.io.IOException;
import java.io.Serializable;

import org.junit.Test;
import org.nuxeo.common.utils.FileUtils;
import org.nuxeo.ecm.core.api.Blob;
import org.nuxeo.ecm.core.api.Blobs;
import org.nuxeo.ecm.core.api.DocumentModel;
import org.nuxeo.ecm.core.api.impl.blob.FileBlob;
import org.nuxeo.template.api.adapters.TemplateBasedDocument;

import static org.junit.Assert.*;

public class TestXSLTProcessing extends SimpleTemplateDocTestCase {

    @Test
    public void testDocumentsAttributes() throws Exception {
        TemplateBasedDocument adapter = setupTestDocs();

        File file = FileUtils.getResourceFileFromContext("data/nuxeoremoting.wsdl");
        Blob fileBlob = Blobs.createBlob(file);
        fileBlob.setFilename("nuxeoremoting.wsdl");

        DocumentModel testDoc = adapter.getAdaptedDoc();
        assertNotNull(testDoc);

        testDoc.setPropertyValue("file:content", (Serializable) fileBlob);
        testDoc = session.saveDocument(testDoc);

        adapter = testDoc.getAdapter(TemplateBasedDocument.class);

        String processorType = adapter.getSourceTemplate(TEMPLATE_NAME).getTemplateType();
        assertEquals("XSLTProcessor", processorType);

        Blob newBlob = adapter.renderWithTemplate(TEMPLATE_NAME);

        String xmlContent = newBlob.getString();
        assertTrue(xmlContent.contains("This page was generated by wsdl-viewer.xsl"));

    }

    @Override
    protected Blob getTemplateBlob() throws IOException {
        File file = FileUtils.getResourceFileFromContext("data/wsdl-viewer.xsl");
        Blob fileBlob = Blobs.createBlob(file);
        fileBlob.setFilename("wsdl-viewer.xsl");
        return fileBlob;
    }

}
